from book import convert, cli, logging


def main():  # pragma: no mutate
    parse = cli.parser()  # pragma: no mutate
    args = parse.parse_args()  # pragma: no mutate
    logging.log.notice(f'Running the program with args: {args}.')  # pragma: no mutate
    print(convert.run(args.completed, args.overall, args.pages))  # pragma: no mutate


if __name__ == '__main__':  # pragma: no mutate
    main()  # pragma: no mutate



import argparse


def parser():
    p = argparse.ArgumentParser(description='Tools for books.')
    p.add_argument('--completed', '-c', action='store', type=str)
    p.add_argument('--overall', '-o', action='store', type=str)
    p.add_argument('--pages', '-p', action='store', type=int)
    return p



from datetime import timedelta
from book.logging import log


def time_to_pages(completed: timedelta, overall: timedelta, pages: int) -> float:
    return (completed / overall) * pages


def str_to_time(time: str) -> timedelta:
    list_time = time.split(':')
    if len(list_time) == 2:
        minutes, seconds = map(lambda x: float(x), list_time)
        hours = 0
    else:
        hours, minutes, seconds = map(lambda x: float(x), list_time)
    return timedelta(hours=hours, minutes=minutes, seconds=seconds)


def run(completed: str, overall: str, pages: int):
    completed_td = str_to_time(time=completed)
    log().notice(f'Parsed completed_td as: {completed_td}')
    overall_td = str_to_time(time=overall)
    log().notice(f'Parsed overall_td as: {overall_td}')
    return time_to_pages(completed_td, overall_td, pages)



from pathlib import Path
from logbook import Logger, RotatingFileHandler


def log(path=None):
    loc = Path(path) if path else Path.home()
    RotatingFileHandler(str(loc / '.audio2book.log')).push_application()
    return Logger('Book')



import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name="audio2book",
    version='0.1.6',
    author="Robert Hughes",
    author_email='roberts.ginger.email@gmail.com',
    install_requires=['logbook'],
    description='Converts audiobook completion into page completion',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://www.github.com/safuya/books',
    packages=['book'],
    package_dir={'book': 'book'},
    entry_points={
        'console_scripts': ['audio2book = book.__main__:main']
    },
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Intended Audience :: End Users/Desktop'
    ])
